<?php
/**
 * File system management tool.
 * 
 * @package: ACWPB
 */

/**
 * Class that accesses the file system.
 */
if ( ! class_exists( 'Rrj_Filesystem' ) ) {
    class Rrj_Filesystem {
        /**
         * Singleton instance of the class
         *
         * @var Rrj_Filesystem
         */
        protected static $instance;

        /**
         * Return the unique instance of Rrj_Filesystem
         *
         * @return  Rrj_Filesystem
         */
        public static function get_instance() {
            if ( null === self::$instance ) {
                self::$instance = new self;
            }

            return self::$instance;
        }

        /**
         * Enqueue the needed JavaScript file.
         */
        public static function enqueue_rfc() {
            wp_enqueue_script( 'rfc/script', plugin_dir_url( __FILE__ ) . 'rfc.js', array( 'jquery' ), null, true );
        }
        
        private function __construct() {}
        
        /**
         * Check if we have credentials for the file system.
         * 
         * @param string|false $directory The directory to check credentals for.
         * 
         * @return boolean $creds
         */
        public function check_creds( $directory = false ) {
            ob_start();
            $creds = request_filesystem_credentials( '', '', false, $directory );
            ob_end_clean();
            return $creds;
        }
        
        /**
         * Get the credential form with its CSS (intended to be used inside an iframe styled by the developer).
         * 
         * @param type $url Where to post the resulting form (should be 'ajaxurl').
         * @param type $type The type of method to use form the form.
         * @param type $directory Directory (context) to get check the credential for.
         * @param type $fields Extra fields to 'pass-through' the credentials form.
         */
        public function get_form( $url, $fields = null, $errors = false, $type = 'POST', $directory = false ) {
            ob_start();
            require plugin_dir_path( __FILE__ ) . 'rfc-form.php';
            return ob_get_clean();
        }
        
        /**
         * Replace the 'direct' absolute path with the Filesystem API path. Useful only when the 'direct' method is not used.
         * Works only with folders.
         * Check https://codex.wordpress.org/Filesystem_API for info
         *
         * @param    string  existing path
         * @return   string  normalized path
         */
        public function normalize_path( $path ) {
            global $wp_filesystem;
            $abs_path = str_replace( '\\', '/', ABSPATH );
            $path = str_replace( '\\', '/', $path );
            if ( false === strpos( $abs_path, $wp_filesystem->abspath() ) ) {
                return false;
            }
            $normalized_path = str_replace( $abs_path, $wp_filesystem->abspath(), $path );
            return $normalized_path;
        }
        
    }
}