<?php
/**
 * Content of the PHP data functions tab.
 *
 * @package ACWPB
 */

$functions = get_option( self::php_functions, array() );

$php_names = get_option( self::PHP_FILENAMES, array() );
$php_files = array();

$has_old_code = false;
foreach( $functions as $key => $value ) {
    if ( isset( $value['code'] ) ) {
        $has_old_code = true;
        break;
    }
    if ( isset( $value['file'] ) ) {
        $php_files[ $key ] = Rrj_Charts::get_function_code( $key );
    }
}
?>
<script type="text/template" id="end-error-notice">
<div id="endError" class="error notice is-dismissible">
    <p></p>
    <button type="button" class="notice-dismiss"><span class="screen-reader-text"><?php esc_html_e( 'Dismiss this notice.', 'rrj-ac' ); ?></span></button>
</div>
</script>
<?php
if ( $has_old_code ) {
    ?>
        <div class="update-nag">
            <p>
                <?php esc_html_e( 'Your PHP functions need to me moved from the database into a file within the WordPress&#39;s upload folder.', 'rrj-ac' ); ?>
                <?php esc_html_e( 'They are still working in the front end by now, but they will stop working in a near future update if not moved into a file.', 'rrj-ac' ); ?>
            </p>
            <p><button class="button-secondary" id="upgrade-functions"><?php esc_html_e( 'Proceed', 'rrj-ac' ); ?></button></p>
        </div>
        <div id="rrj-rfc">
        </div>
    <?php
    return;
}

?>
<script type="text/javascript">
	<?php if ( empty( $functions ) ) : ?>
	var rrjPhpFunctions = {};
	<?php else : ?>
	var rrjPhpFunctions = <?php echo wp_json_encode( $functions ) ?>;
	<?php endif; ?>
    <?php if ( empty( $php_files ) ) : ?>
    var rrjPhpFiles = {};
    <?php else : ?>
    var rrjPhpFiles = <?php echo wp_json_encode( $php_files ); ?>
    <?php endif; ?>
</script>
<div class="form-wrap">
	<form name="php-functions" id="php-functions">
		<h4 class="section-head"><?php esc_html_e( 'New function', 'rrj-ac' ); ?></h4>
		<div class="form-field">
			<input type="text" id="new-function-name" style="width:30em;margin:auto 1em;" value="" />
			<button class="button-secondary" id="new-function"><?php esc_html_e( 'create function', 'rrj-ac' ); ?></button>
			<p class="description"><?php esc_html_e( 'The name used to refer to this function from JS Data, (Not necessarily a valid PHP function name)', 'rrj-ac' ); ?></p>
		</div>

		<h4 class="section-head"><?php esc_html_e( 'Edit function', 'rrj-ac' ); ?></h4>

		<div class="form-field" style="border:none;">
			<label for="function-selector"><span><?php esc_html_e( 'Select a function', 'rrj-ac' ) ?><span></label>
			<select id="function-selector" style="margin-bottom:1em;">
			<?php if ( empty( $functions ) ) : ?>
			<option value=""><?php esc_html_e( 'no function found', 'rrj-ac' ) ?></option>
			<?php else : ?>
				<option value=""><?php esc_html_e( ' --Choose a function-- ', 'rrj-ac' ) ?></option>
				<?php foreach ( $functions as $key => $value ) : ?>
				<option value="<?php echo esc_attr( $key ) ?>"><?php echo esc_html( $key ); ?></option>
				<?php endforeach; ?>
			<?php endif; ?>
			</select>
		</div>

		<div class="form-field" id="function-editor" >

			<label for="php-code-editor"><span><?php esc_html_e( 'PHP code', 'rrj-ac' ) ?><span></label>
			<textarea id="php-code-editor" rows="20" name="function-code"></textarea>
			<p class="description"><i class="dashicons dashicons-info"></i>&nbsp;<?php echo wp_kses( __( 'As of version 1.6, always start your code with <code><?php</code>. Do not use the short opening tag.', 'rrj-ac' ), array( 'code' => true ) ) ?></p>
            <br />
            
			<input type="hidden" name="function-name" value="" />

			<label for="storage"><span><?php esc_html_e( 'Results caching', 'rrj-ac' ) ?><span></label>
			<select id="storage" name="function-storage">
				<option value="disabled"><?php esc_html_e( 'evaluate every time', 'rrj-ac' ) ?></option>
				<option value="5min"><?php esc_html_e( '5 minutes', 'rrj-ac' ) ?></option>
				<option value="15min"><?php esc_html_e( '15 minutes', 'rrj-ac' ) ?></option>
				<option value="30min"><?php esc_html_e( '30 minutes', 'rrj-ac' ) ?></option>
				<option value="1h"><?php esc_html_e( 'one hour', 'rrj-ac' ) ?></option>
				<option value="2h"><?php esc_html_e( '2 hours', 'rrj-ac' ) ?></option>
				<option value="3h"><?php esc_html_e( '3 hours', 'rrj-ac' ) ?></option>
				<option value="6h"><?php esc_html_e( '6 hours', 'rrj-ac' ) ?></option>
				<option value="12h"><?php esc_html_e( '12 hours', 'rrj-ac' ) ?></option>
				<option value="24h"><?php esc_html_e( '24 hours', 'rrj-ac' ) ?></option>
				<option value="2d"><?php esc_html_e( '2 days', 'rrj-ac' ) ?></option>
			</select>
			<p class="description"><?php esc_html_e( 'how much time the stored result will be served to charts before re-evaluating the PHP code', 'rrj-ac' ) ?></p>

			<div class="submit" style="float:left;">
				<button class="button-secondary" id="execute-test" disabled><?php esc_html_e( 'Test the code', 'rrj-ac' ) ?></button>
				<a class="button-secondary" id="show-conditionals"><?php esc_html_e( 'Conditionals', 'rrj-ac' ) ?></a>
				<p><i class="dashicons dashicons-info"></i>&nbsp;<?php esc_html_e( 'testing a code does no involve caching, the code will always be evaluated.', 'rrj-ac' ) ?></p>
			</div>
			<div class="submit" style="float:right">
				<button class="button-secondary" id="delete-function"><?php esc_html_e( 'Delete function', 'rrj-ac' ); ?></button>
				<button class="button-primary" id="save-function"><?php esc_html_e( 'Save function', 'rrj-ac' ); ?></button>
			</div>

			<br style="clear:both;" />

			<div id="conditionals" style="display:none">
				<label><span><?php esc_html_e( 'Conditionals', 'rrj-ac' ) ?></span></label>
				<label class="condlabel"><input type="checkbox" class="conditional" data-fn="is_front_page" /><code>is_front_page()</code></label>
				<label class="condlabel"><input type="checkbox" class="conditional" data-fn="is_home" /><code>is_home()</code></label>
				<label class="condlabel"><input type="checkbox" class="conditional" data-fn="is_singular" /><code>is_singular()</code></label>
				<label class="condlabel"><input type="checkbox" class="conditional" data-fn="is_page" /><code>is_page()</code></label>
				<label class="condlabel"><input type="checkbox" class="conditional" data-fn="is_user_logged_in" /><code>is_user_logged_in()</code></label>
			</div>

			<div id="response-div" style="display:none">
				<label><span><?php esc_html_e( 'Server response', 'rrj-ac' ) ?></span></label>
				<div></div>
			</div>

            <div id="rrj-rfc">
            </div>
		</div>

	</form>
</div>
<script type="text/javascript">
var rrjAcI18n = {
	'unknownResponse': '<?php esc_html_e( 'Unknown response received from the server (can not be converted to JSON). Original response : <p><strong>%s</strong></p>', 'rrj-ac' ) ?>',
};
</script>